@@ -1,22 +1,8 @@
 /*  This file is part of the KDE libraries
- *  Copyright 2013 Kevin Ottens <ervin+bluesystems@kde.org>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Kevin Ottens <ervin+bluesystems@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #ifndef KDEPLATFORMTHEME_H
 #define KDEPLATFORMTHEME_H
@@ -33,7 +19,6 @@ class X11Integration;
 class QIconEngine;
 class QWindow;
 
-
 class KdePlatformTheme : public QPlatformTheme
 {
 public:
@@ -41,8 +26,7 @@ public:
     ~KdePlatformTheme() override;
 
     QVariant themeHint(ThemeHint hint) const override;
-    QIcon fileIcon(const QFileInfo &fileInfo,
-                           QPlatformTheme::IconOptions iconOptions) const override;
+    QIcon fileIcon(const QFileInfo &fileInfo, QPlatformTheme::IconOptions iconOptions) const override;
 
     const QPalette *palette(Palette type = SystemPalette) const override;
     const QFont *font(Font type) const override;
@@ -70,7 +54,6 @@ private:
     KFontSettingsData *m_fontsData = nullptr;
     QScopedPointer<KWaylandIntegration> m_kwaylandIntegration;
     QScopedPointer<X11Integration> m_x11Integration;
-
 };
 
 #endif // KDEPLATFORMTHEME_H
