@@ -1,45 +1,14 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 Dmitry Shachnev <mitya57@gmail.com>
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtGui module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+/*
+
+    SPDX-FileCopyrightText: 2016 Dmitry Shachnev <mitya57@gmail.com>
+    SPDX-FileContributor: The Qt Company <https://www.qt.io/licensing/>
+
+    SPDX-License-Identifier: LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KFQF-Accepted-GPL OR LicenseRef-Qt-Commercial
+
+*/
 
 #include "qdbusmenubar_p.h"
 
-
 QT_BEGIN_NAMESPACE
 
 /* note: do not change these to QStringLiteral;
@@ -54,15 +23,9 @@ QDBusMenuBar::QDBusMenuBar()
     , m_menuAdaptor(new QDBusMenuAdaptor(m_menu))
 {
     QDBusMenuItem::registerDBusTypes();
-    connect(m_menu, &QDBusPlatformMenu::propertiesUpdated,
-            m_menuAdaptor, &QDBusMenuAdaptor::ItemsPropertiesUpdated);
-    connect(m_menu, &QDBusPlatformMenu::updated,
-            m_menuAdaptor, &QDBusMenuAdaptor::LayoutUpdated);
-
-    // This signal is new in Qt 5.8 but distros might have backported it, hence a runtime look-up
-    if (m_menu->metaObject()->indexOfSignal("popupRequested(int,uint)") != -1) {
-        connect(m_menu, SIGNAL(popupRequested(int,uint)), m_menuAdaptor, SIGNAL(ItemActivationRequested(int,uint)));
-    }
+    connect(m_menu, &QDBusPlatformMenu::propertiesUpdated, m_menuAdaptor, &QDBusMenuAdaptor::ItemsPropertiesUpdated);
+    connect(m_menu, &QDBusPlatformMenu::updated, m_menuAdaptor, &QDBusMenuAdaptor::LayoutUpdated);
+    connect(m_menu, SIGNAL(popupRequested(int,uint)), m_menuAdaptor, SIGNAL(ItemActivationRequested(int,uint)));
 }
 
 QDBusMenuBar::~QDBusMenuBar()
@@ -169,8 +132,7 @@ void QDBusMenuBar::registerMenuBar()
     QDBusPendingReply<> r = registrar.RegisterWindow(static_cast<uint>(window()->winId()), QDBusObjectPath(m_objectPath));
     r.waitForFinished();
     if (r.isError()) {
-        qWarning("Failed to register window menu, reason: %s (\"%s\")",
-                 qUtf8Printable(r.error().name()), qUtf8Printable(r.error().message()));
+        qWarning("Failed to register window menu, reason: %s (\"%s\")", qUtf8Printable(r.error().name()), qUtf8Printable(r.error().message()));
         connection.unregisterObject(m_objectPath);
     }
 }
@@ -184,8 +146,7 @@ void QDBusMenuBar::unregisterMenuBar()
         QDBusPendingReply<> r = registrar.UnregisterWindow(static_cast<uint>(window()->winId()));
         r.waitForFinished();
         if (r.isError())
-            qWarning("Failed to unregister window menu, reason: %s (\"%s\")",
-                     qUtf8Printable(r.error().name()), qUtf8Printable(r.error().message()));
+            qWarning("Failed to unregister window menu, reason: %s (\"%s\")", qUtf8Printable(r.error().name()), qUtf8Printable(r.error().message()));
     }
 
     if (!m_objectPath.isEmpty())
