@@ -1,31 +1,17 @@
 /*  This file is part of the KDE libraries
- *  Copyright 2015 Martin Gräßlin <mgraesslin@kde.org>
- *  Copyright 2016 Marco Martin <mart@kde.org>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2016 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "x11integration.h"
 
-#include <QCoreApplication>
-#include <QX11Info>
-#include <QPlatformSurfaceEvent>
-#include <QGuiApplication>
-#include <QWindow>
 #include <NETWM>
+#include <QCoreApplication>
+#include <QGuiApplication>
+#include <QPlatformSurfaceEvent>
+#include <QWindow>
+#include <QX11Info>
 
 #include <KWindowEffects>
 
@@ -48,18 +34,18 @@ void X11Integration::init()
 
 bool X11Integration::eventFilter(QObject *watched, QEvent *event)
 {
-    //the drag and drop window should NOT be a tooltip
-    //https://bugreports.qt.io/browse/QTBUG-52560
+    // the drag and drop window should NOT be a tooltip
+    // https://bugreports.qt.io/browse/QTBUG-52560
     if (event->type() == QEvent::Show && watched->inherits("QShapedPixmapWindow")) {
-        //static cast should be safe there
+        // static cast should be safe there
         QWindow *w = static_cast<QWindow *>(watched);
         NETWinInfo info(QX11Info::connection(), w->winId(), QX11Info::appRootWindow(), NET::WMWindowType, NET::Properties2());
         info.setWindowType(NET::DNDIcon);
         // TODO: does this flash the xcb connection?
     }
     if (event->type() == QEvent::PlatformSurface) {
-        if (QWindow *w = qobject_cast<QWindow*>(watched)) {
-            QPlatformSurfaceEvent *pe = static_cast<QPlatformSurfaceEvent*>(event);
+        if (QWindow *w = qobject_cast<QWindow *>(watched)) {
+            QPlatformSurfaceEvent *pe = static_cast<QPlatformSurfaceEvent *>(event);
             if (!w->flags().testFlag(Qt::ForeignWindow)) {
                 if (pe->surfaceEventType() == QPlatformSurfaceEvent::SurfaceCreated) {
                     auto flags = w->flags();
@@ -75,7 +61,7 @@ bool X11Integration::eventFilter(QObject *watched, QEvent *event)
                         }
 
                         // QWINDOWSIZE_MAX from qwindow_p.h
-                        const auto maxWindowSize = ((1<<24)-1);
+                        const auto maxWindowSize = ((1 << 24) - 1);
                         if (w->maximumSize() == QSize(maxWindowSize, maxWindowSize)) {
                             flags.setFlag(Qt::WindowMaximizeButtonHint, true);
                         }
@@ -126,8 +112,7 @@ void X11Integration::installColorScheme(QWindow *w)
     if (path.isEmpty()) {
         xcb_delete_property(c, w->winId(), atom);
     } else {
-        xcb_change_property(c, XCB_PROP_MODE_REPLACE, w->winId(), atom, XCB_ATOM_STRING,
-                            8, path.size(), qPrintable(path));
+        xcb_change_property(c, XCB_PROP_MODE_REPLACE, w->winId(), atom, XCB_ATOM_STRING, 8, path.size(), qPrintable(path));
     }
 }
 
@@ -172,7 +157,6 @@ void X11Integration::setWindowProperty(QWindow *window, const QByteArray &name,
     if (value.isEmpty()) {
         xcb_delete_property(c, window->winId(), atom);
     } else {
-        xcb_change_property(c, XCB_PROP_MODE_REPLACE, window->winId(), atom, XCB_ATOM_STRING,
-                            8, value.length(), value.constData());
+        xcb_change_property(c, XCB_PROP_MODE_REPLACE, window->winId(), atom, XCB_ATOM_STRING, 8, value.length(), value.constData());
     }
 }
